@@ -3,7 +3,7 @@
 #include "config.h"
 
 #include "Environment.h"
-#include <buffy/wibble/exception.h>
+#include <wibble/exception.h>
 
 #include <sys/types.h>  // fork, stat, utimes
 #include <unistd.h>     // fork, execl, isatty, pipe
