@@ -22,7 +22,7 @@
 
 #include "FolderList.h"
 
-#include <buffy/Config.h>
+#include <buffy/config/Config.h>
 
 #include <map>
 #include <iostream>
@@ -35,7 +35,6 @@
 #include "Environment.h"
 
 using namespace std;
-using namespace stringf;
 using namespace buffy;
 
 static const int VF_ALWAYS		= 0x0001;
@@ -61,10 +60,10 @@ bool FolderList::on_event(GdkEvent* e)
 
 			Gtk::TreeModel::Row row = *sortedModel->get_iter(path);
 			MailFolder folder = row[folderListModelColumns.folder];
-			verbose("Clicked on %.*s\n", PFSTR(folder.path()));
-			Config& conf(Environment::get().config());
-			ConfigItemString forceview = conf.folder(folder).get("forceview", "false");
-			ConfigItemString forcehide = conf.folder(folder).get("forcehide", "false");
+			verbose("Clicked on %s\n", folder.path().c_str());
+			config::Config& conf(Environment::get().config());
+			bool forceview = conf.folder(folder).forceview();
+			bool forcehide = conf.folder(folder).forcehide();
 			cerr << "foo0" << endl;
 
 			folderList.get_selection()->select(row);
@@ -74,7 +73,7 @@ bool FolderList::on_event(GdkEvent* e)
 			itemPopup.items().clear();
 			itemPopup.items().push_back(Gtk::Menu_Helpers::CheckMenuElem("View always"));
 			item = dynamic_cast<Gtk::CheckMenuItem*>(&itemPopup.items().back());
-			item->set_active(forceview.get() == "true");
+			item->set_active(forceview);
 			item->signal_toggled().connect(
 						sigc::bind< MailFolder >(
 							sigc::mem_fun(*this, &FolderList::toggle_view_always), folder));
@@ -83,7 +82,7 @@ bool FolderList::on_event(GdkEvent* e)
 
 			itemPopup.items().push_back(Gtk::Menu_Helpers::CheckMenuElem("Hide always"));
 			item = dynamic_cast<Gtk::CheckMenuItem*>(&itemPopup.items().back());
-			item->set_active(forcehide.get() == "true");
+			item->set_active(forcehide);
 			item->signal_toggled().connect(
 						sigc::bind< MailFolder >(
 							sigc::mem_fun(*this, &FolderList::toggle_hide_always), folder));
@@ -169,19 +168,9 @@ void FolderList::toggle_hide_always(const MailFolder& folder)
 {
 // TODO: set the per-list configuration
 // TODO: honor per-list configuration when filtering
-	Config& conf(Environment::get().config());
-	ConfigItemString fh = conf.folder(folder).get("forcehide", "false");
-	ConfigItemString fv = conf.folder(folder).get("forceview", "false");
-
-	if (fh.get() == "true")
-		fh.set("false");
-	else
-	{
-		fh.set("true");
-		if (fv.get() == "true")
-			fv.set("false");
-	}
-
+	config::Config& conf(Environment::get().config());
+	config::FolderNode fc = conf.folder(folder);
+	fc.setForceHide(!fc.forcehide());
 	configureFilter(conf);
 }
 
@@ -189,20 +178,10 @@ void FolderList::toggle_view_always(const MailFolder& folder)
 {
 // TODO: set the per-list configuration
 // TODO: honor per-list configuration when filtering
-	Config& conf(Environment::get().config());
-	ConfigItemString fh = conf.folder(folder).get("forcehide", "false");
-	ConfigItemString fv = conf.folder(folder).get("forceview", "false");
-
-	cerr << "Currently: \"" << fv.get() << "\"" << endl;
-
-	if (fv.get() == "true")
-		fv.set("false");
-	else
-	{
-		fv.set("true");
-		if (fh.get() == "true")
-			fh.set("false");
-	}
+	config::Config& conf(Environment::get().config());
+	config::FolderNode fc = conf.folder(folder);
+	//cerr << "Currently: \"" << folder.get("forceview") << "\"" << endl;
+	fc.setForceView(!fc.forceview());
 	configureFilter(conf);
 }
 
@@ -298,15 +277,10 @@ FolderList::FolderList()
 	column->set_sort_column(folderListModelColumns.msg_flagged);
 
 	// Restore sort order if previously saved
-	Config& conf = Environment::get().config();
-	ConfigItemDictionary prefs = conf.application("buffy");
-	string sorted = prefs.get("sorted", "0").get();
-	if (atoi(sorted.c_str()))
-	{
-		string id = prefs.get("sort_col_id", "0").get();
-		string order = prefs.get("sort_order", "0").get();
-		sortedModel->set_sort_column_id(atoi(id.c_str()), (Gtk::SortType)atoi(order.c_str()));
-	}
+	config::Config& conf = Environment::get().config();
+	config::Node prefs(conf.application("buffy"));
+	if (prefs.getBool("sorted"))
+		sortedModel->set_sort_column_id(prefs.getInt("sort_col_id"), (Gtk::SortType)prefs.getInt("sort_order"));
 
 	Glib::RefPtr<Gtk::TreeSelection> folderListSelection = folderList.get_selection();
 	folderListSelection->set_mode(Gtk::SELECTION_SINGLE);
@@ -325,12 +299,12 @@ void FolderList::on_sort_column_changed()
 	bool res = sortedModel->get_sort_column_id(id, order);
 	//fprintf(stderr, "sort column changed id %d order %d res %d\n", id, order, res);
 
-	Config& conf = Environment::get().config();
-	ConfigItemDictionary prefs = conf.application("buffy");
+	config::Config& conf = Environment::get().config();
+	config::Node prefs = conf.application("buffy");
 
-	prefs.get("sorted", fmt(res)).set(fmt(res));
-	prefs.get("sort_col_id", fmt(id)).set(fmt(id));
-	prefs.get("sort_order", fmt(order)).set(fmt(order));
+	prefs.setBool("sorted", res);
+	prefs.setInt("sort_col_id", id);
+	prefs.setInt("sort_order", order);
 }
 
 void FolderList::consume(MailFolder& folder)
@@ -349,16 +323,15 @@ void FolderList::consume(MailFolder& folder)
 	row[folderListModelColumns.msg_total] = folder.getMsgTotal();
 	row[folderListModelColumns.msg_flagged] = folder.getMsgFlagged();
 
-	Config& conf(Environment::get().config());
+	config::Config& conf(Environment::get().config());
 	int flags = 
-		(conf.view_empty().get() ? VF_ALWAYS : 0) |
-		(conf.view_read().get() ? VF_NONEMPTY : 0) |
-		(conf.view_important().get() ? VF_IMPORTANT : 0);
-	ConfigItemString fv = conf.folder(folder).get("forceview", "false");
-	ConfigItemString fh = conf.folder(folder).get("forcehide", "false");
-	if (fv.get() == "true")
+		(conf.view().empty() ? VF_ALWAYS : 0) |
+		(conf.view().read() ? VF_NONEMPTY : 0) |
+		(conf.view().important() ? VF_IMPORTANT : 0);
+	config::FolderNode fc = conf.folder(folder);
+	if (fc.forceview())
 		flags |= VF_ALWAYS;
-	if (fh.get() == "true")
+	if (fc.forcehide())
 		flags |= VF_NEVER;
 	row[folderListModelColumns.view_flags] = flags;
 
@@ -397,12 +370,12 @@ bool FolderList::do_timer_tick()
 	return true;
 }
 
-void FolderList::configureFilter(Config& conf)
+void FolderList::configureFilter(config::Config& conf)
 {
 	int baseFlags = 
-		(conf.view_empty().get() ? VF_ALWAYS : 0) |
-		(conf.view_read().get() ? VF_NONEMPTY : 0) |
-		(conf.view_important().get() ? VF_IMPORTANT : 0);
+		(conf.view().empty() ? VF_ALWAYS : 0) |
+		(conf.view().read() ? VF_NONEMPTY : 0) |
+		(conf.view().important() ? VF_IMPORTANT : 0);
 
 	for (Gtk::TreeModel::Children::const_iterator i = folderListModel->children().begin();
 			i != folderListModel->children().end(); i++)
@@ -410,11 +383,10 @@ void FolderList::configureFilter(Config& conf)
 		int flags = baseFlags;
 		Gtk::TreeModel::Row row = *i;
 		MailFolder folder = row[folderListModelColumns.folder];
-		ConfigItemString fv = conf.folder(folder).get("forceview", "false");
-		ConfigItemString fh = conf.folder(folder).get("forcehide", "false");
-		if (fv.get() == "true")
+		config::FolderNode fc(conf.folder(folder));
+		if (fc.forceview())
 			flags |= VF_ALWAYS;
-		if (fh.get() == "true")
+		if (fc.forcehide())
 			flags |= VF_NEVER;
 
 		row[folderListModelColumns.view_flags] = flags;
