@@ -29,7 +29,7 @@
 
 //#include "Environment.h"
 #include <buffy/MailFolder.h>
-#include <buffy/wibble/exception.h>
+#include <wibble/exception.h>
 #include "CommandlineParser.h"
 
 #include <vector>
